summaryrefslogtreecommitdiffstats
path: root/src/include/usr/fapi2
diff options
context:
space:
mode:
authorCaleb Palmer <cnpalmer@us.ibm.com>2018-11-12 15:49:59 -0600
committerZane C. Shelley <zshelle@us.ibm.com>2018-11-16 11:40:11 -0600
commitc525c33e2020dab4eae2aa5b39bb4ad69111faf0 (patch)
treef5526abcb0b6f00ecd87faf2e846b5016dc4c25e /src/include/usr/fapi2
parent32744984916885b8a25dfca48fe8e5202e1e28ed (diff)
downloadtalos-hostboot-c525c33e2020dab4eae2aa5b39bb4ad69111faf0.tar.gz
talos-hostboot-c525c33e2020dab4eae2aa5b39bb4ad69111faf0.zip
Dram Repairs VPD favor FAPI trgts and getHelperAttr improvements
Change-Id: I52128219be32b9cfb621118527e686d61dfec63a RTC: 199027 Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/68705 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Reviewed-by: Zane C. Shelley <zshelle@us.ibm.com>
Diffstat (limited to 'src/include/usr/fapi2')
-rw-r--r--src/include/usr/fapi2/attribute_service.H8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/include/usr/fapi2/attribute_service.H b/src/include/usr/fapi2/attribute_service.H
index c7c0df3ab..8a5787841 100644
--- a/src/include/usr/fapi2/attribute_service.H
+++ b/src/include/usr/fapi2/attribute_service.H
@@ -280,22 +280,22 @@ ReturnCode fapiAttrSetBadDqBitmap( const Target<TARGET_TYPE_ALL>& i_fapiTarget,
/// @brief This function is called by the FAPI_ATTR_GET macro when getting
/// the Row Repair Data attribute. It should not be called directly.
///
/// @param[in] i_fapiDimm DIMM target pointer
/// @param[out] o_data Row Repair Data
/// @return ReturnCode. Zero on success, else platform specified error
///
-ReturnCode getRowRepairData( const Target<TARGET_TYPE_ALL>& i_fapiDimm,
+ReturnCode getRowRepairData( const Target<TARGET_TYPE_ALL>& i_fapiTarget,
ATTR_ROW_REPAIR_DATA_Type (&o_data) );
///
/// @brief This function is called by the FAPI_ATTR_SET macro when setting
/// the Row Repair Data attribute. It should not be called directly.
///
/// @param[in] i_fapiDimm DIMM target pointer
/// @param[in] i_data Row Repair Data
/// @return ReturnCode. Zero on success, else platform specified error
///
-ReturnCode setRowRepairData( const Target<TARGET_TYPE_ALL>& i_fapiDimm,
+ReturnCode setRowRepairData( const Target<TARGET_TYPE_ALL>& i_fapiTarget,
ATTR_ROW_REPAIR_DATA_Type (&i_data) );
/// @brief This function is called by the FAPI_ATTR_GET macro when getting
OpenPOWER on IntegriCloud
@@ -280,22 +280,22 @@ ReturnCode fapiAttrSetBadDqBitmap( const Target<TARGET_TYPE_ALL>& i_fapiTarget,
/// the Row Repair Data attribute. It should not be called directly.
///
-/// @param[in] i_fapiDimm DIMM target pointer
+/// @param[in] i_fapiTarget DIMM target pointer
/// @param[out] o_data Row Repair Data
/// @return ReturnCode. Zero on success, else platform specified error
@@ -280,22 +280,22 @@ ReturnCode fapiAttrSetBadDqBitmap( const Target<TARGET_TYPE_ALL>& i_fapiTarget,
/// the Row Repair Data attribute. It should not be called directly.
///
-/// @param[in] i_fapiDimm DIMM target pointer
+/// @param[in] i_fapiTarget DIMM target pointer
/// @param[in] i_data Row Repair Data
/// @return ReturnCode. Zero on success, else platform specified error